#[repr(transparent)]pub(super) struct Repr(NonNull<()>, PhantomData<ErrorData<Box<Custom>>>);Available on 64-bit and non-
target_os=uefi only.Expand description
The internal representation.
See the module docs for more, this is just a way to hack in a check that we indeed are not unwind-safe.
Tuple Fields
0: NonNull<()>1: PhantomData<ErrorData<Box<Custom>>>Implementations
Sourceimpl Repr
impl Repr
pub(super) fn new_custom(b: Box<Custom>) -> Self
pub(super) fn new_os(code: RawOsError) -> Self
pub(super) fn new_simple(kind: ErrorKind) -> Self
pub(super) const fn new_simple_message(m: &'static SimpleMessage) -> Self
pub(super) fn data(&self) -> ErrorData<&Custom>
pub(super) fn data_mut(&mut self) -> ErrorData<&mut Custom>
pub(super) fn into_data(self) -> ErrorData<Box<Custom>>